# API

Import Scanpy as:

```
import scanpy as sc
```

```{note}
Additional functionality is available in the broader {doc}`ecosystem <../ecosystem>`, with some tools being wrapped in the {mod}`scanpy.external` module.
```

```{toctree}
:maxdepth: 2

preprocessing
tools
plotting
io
get
queries
metrics
experimental
classes
settings
datasets
deprecated
```
